import arrow
import pytest

from calendar_utils.parser import (
    parse_ical,
    process_ical,
    set_event_duration,
    split_events,
)


def test_parse_ical(sample, snapshot):
    events = parse_ical(sample)
    snapshot.assert_match(events)


@pytest.mark.freeze_time("2020-02-02")
def test_split_events(sample, snapshot):
    past_events, future_events = split_events(parse_ical(sample))
    snapshot.assert_match(past_events)
    snapshot.assert_match(future_events)


def test_set_event_duration__all_day():
    event = {
        "begin": arrow.get("2020-02-03T00:00:00Z"),
        "end": arrow.get("2020-02-04T00:00:00Z"),
        "all_day": True,
    }
    out = set_event_duration(event)
    assert out["duration"] == "celý den"


def test_set_event_duration__hours():
    event = {
        "begin": arrow.get("2020-02-03T08:00:00Z"),
        "end": arrow.get("2020-02-03T12:25:00Z"),
        "all_day": False,
    }
    out = set_event_duration(event)
    assert out["duration"] == "8:00 - 12:25"


def test_set_event_duration__days():
    event = {
        "begin": arrow.get("2020-02-03T09:15:00Z"),
        "end": arrow.get("2020-02-04T22:30:00Z"),
        "all_day": False,
    }
    out = set_event_duration(event)
    assert out["duration"] == "9:15 - 22:30 (4.2.)"


@pytest.mark.freeze_time("2020-02-02")
def test_process_ical(sample, snapshot):
    past_events, future_events = process_ical(sample)
    snapshot.assert_match(past_events)
    snapshot.assert_match(future_events)
